@@ -146,7 +146,7 @@ class SOAPView(BrowserView):
             request.__dict__.get('_showAssembly', False),
             request.__dict__.get('_showTemplates', False),
             inTheNameOf)
-        if not showEmptyValues:
+        if infos and not showEmptyValues:
             # remove empty data
             for k, v in infos[0].__dict__.items():
                 if not v:
@@ -190,12 +190,15 @@ class SOAPView(BrowserView):
             request.__dict__.get('_showAssembly', False),
             request.__dict__.get('_showTemplates', False),
             inTheNameOf)
-        if not showEmptyValues:
-            # remove empty data
-            for k, v in infos[0].__dict__.items():
-                if not v:
-                    delattr(infos[0], k)
-        response.__dict__ = infos[0].__dict__
+        if infos:
+            if not showEmptyValues:
+                # remove empty data
+                for k, v in infos[0].__dict__.items():
+                    if not v:
+                        delattr(infos[0], k)
+            response.__dict__ = infos[0].__dict__
+        else:
+            response.__dict__ = {}
         return response
 
     def getItemTemplateRequest(self, request, response):
@@ -459,7 +462,10 @@ class SOAPView(BrowserView):
                 itemInfo._creator = item.Creator()
                 itemInfo._creation_date = localtime(item.created())
                 itemInfo._modification_date = localtime(item.modified())
-                itemInfo._category = item.getCategory()
+                # keep the original category/proposingGroup magic
+                category_or_proposing_group = item.getCategory() and \
+                    item.getCategory(theObject=True) or item.getProposingGroup(theObject=True)
+                itemInfo._category = category_or_proposing_group.getId()
                 itemInfo._description = item.getRawDescription()
                 itemInfo._detailedDescription = item.getRawDetailedDescription()
                 itemInfo._decision = item.getRawDecision(keepWithNext=False)
@@ -467,11 +473,12 @@ class SOAPView(BrowserView):
                 itemInfo._preferredMeeting = not preferred == ITEM_NO_PREFERRED_MEETING_VALUE and preferred or ''
                 preferredMeeting_brains = uid_catalog.searchResults(UID=preferred)
                 preferredMeeting = preferredMeeting_brains and preferredMeeting_brains[0].getObject() or None
-                itemInfo._preferred_meeting_date = localtime(preferredMeeting and preferredMeeting.getDate() or noDate)
+                itemInfo._preferred_meeting_date = \
+                    preferredMeeting and preferredMeeting.date.utctimetuple() or localtime(noDate)
                 itemInfo._review_state = wfTool.getInfoFor(item, 'review_state')
                 meeting = item.hasMeeting() and item.getMeeting()
                 itemInfo._meeting = meeting and meeting.UID() or None
-                itemInfo._meeting_date = localtime(meeting and meeting.getDate() or noDate)
+                itemInfo._meeting_date = meeting and meeting.date.utctimetuple() or localtime(noDate)
                 itemInfo._absolute_url = item.absolute_url()
                 itemInfo._externalIdentifier = item.getField('externalIdentifier').getAccessor(item)()
                 itemInfo._extraInfos = {}
@@ -490,7 +497,7 @@ class SOAPView(BrowserView):
                                                                                 domain='plone',
                                                                                 context=portal.REQUEST)
                     # add the category title
-                    itemInfo._extraInfos['category_title'] = item.getCategory(theObject=True).Title()
+                    itemInfo._extraInfos['category_title'] = category_or_proposing_group.Title()
                     # add the creator fullname
                     itemInfo._extraInfos['creator_fullname'] = tool.getUserName(itemInfo._creator)
                 if showAnnexes:
@@ -520,7 +527,7 @@ class SOAPView(BrowserView):
                         # contacts
                         # attendees
                         assembly_lines.append('Attendees')
-                        attendees = item.getAttendees(theObjects=True)
+                        attendees = item.get_attendees(the_objects=True)
                         attendees_lines = []
                         for attendee in attendees:
                             attendees_lines.append(attendee.get_short_title())
@@ -528,7 +535,7 @@ class SOAPView(BrowserView):
 
                         # absents
                         assembly_lines.append('Absents')
-                        absents = item.getItemAbsents(theObjects=True)
+                        absents = item.get_item_absents(the_objects=True)
                         absents_lines = []
                         for absent in absents:
                             absents_lines.append(absent.get_short_title())
@@ -536,7 +543,7 @@ class SOAPView(BrowserView):
 
                         # excused
                         assembly_lines.append('Excused')
-                        excused = item.getItemExcused(theObjects=True)
+                        excused = item.get_item_excused(the_objects=True)
                         excused_lines = []
                         for excused_contact in excused:
                             excused_lines.append(excused_contact.get_short_title())
@@ -684,14 +691,15 @@ class SOAPView(BrowserView):
                 meeting = brain.getObject()
                 meetingInfo = MeetingInfo()
                 meetingInfo._UID = meeting.UID()
-                meetingInfo._date = localtime(meeting.getDate())
+                meetingInfo._date = meeting.date.utctimetuple()
+
+                logger.info('MeetingConfig at %s SOAP accessed by "%s" to get meetings accepting items.' %
+                            (cfg.absolute_url_path(), memberId))
                 res.append(meetingInfo,)
         finally:
             # fallback to original user calling the SOAP method
             if inTheNameOf:
                 setSecurityManager(oldsm)
-        logger.info('MeetingConfig at %s SOAP accessed by "%s" to get meetings accepting items.' %
-                    (cfg.absolute_url_path(), memberId))
         return res
 
     def _createItem(self,
@@ -879,7 +887,7 @@ class SOAPView(BrowserView):
             for field in MeetingItem.schema.fields():
                 fieldName = field.getName()
                 if fieldName in managedFieldIds and field.widget.getName() in ['RichWidget', 'VisualWidget', ]:
-                        htmlFieldIds.append(fieldName)
+                    htmlFieldIds.append(fieldName)
             warnWrongHTML = False
             if cleanHtml:
                 cleaner = Cleaner()
